////////////////////////////////////////////////////////////////////////
// schedule.cpp
// generated with ecppc
//

#include <tnt/ecpp.h>
#include <tnt/httprequest.h>
#include <tnt/httpreply.h>
#include <tnt/httpheader.h>
#include <tnt/http.h>
#include <tnt/data.h>
#include <tnt/componentfactory.h>
#include <cxxtools/log.h>
#include <stdexcept>

log_define("component.schedule")

// <%pre>
#line 1 "schedule.ecpp"


#include <livefeatures.h>
#include <setup.h>
#include <tools.h>
#include <epg_events.h>
#include <recman.h>


#include <vdr/config.h>
using namespace std;
using namespace vdrlive;

void addAllRecordings(list<RecordingsItemPtr> &RecItems, RecordingsTreePtr &RecordingsTree, vector<string> &P){
  for (RecordingsMap::iterator iter = RecordingsTree->begin(P); iter != RecordingsTree->end(P);  ++iter) {
        RecordingsItemPtr recItem = iter->second;
        if (!recItem->IsDir()) {
                RecItems.push_back(recItem);
        } else {
                vector<string> pp(P);
                pp.push_back(recItem->Name());
                addAllRecordings(RecItems, RecordingsTree, pp);
        }
  }
  RecItems.sort(RecordingsItemPtrCompare::ByAscendingName);
}

// compare function for std::lower_bound / std::upper_bound
bool compRecItemName(const RecordingsItemPtr &first, const RecordingsItemPtr &second) {
  return first->NameForCompare().compare(second->NameForCompare() ) < 0;
}

bool searchNameDesc(RecordingsItemPtr &RecItem, list<RecordingsItemPtr> &RecItems, const string &Name, const string &ShortText, const string &Description, long Duration) {
  if(RecItems.begin() == RecItems.end() ) return false;  // there are no recordings

// find all recordings with equal name
  RecordingsItemPtr dummy (new RecordingsItemDummy(Name, ShortText, Description, Duration));
  list<RecordingsItemPtr>::iterator recIterLowName = std::lower_bound (RecItems.begin(), RecItems.end(), dummy, compRecItemName);
  list<RecordingsItemPtr>::iterator recIterUpName  = std::upper_bound (recIterLowName  , RecItems.end(), dummy, compRecItemName);
  if ( recIterLowName == recIterUpName ) return false; // there is no recording with this name


// find all recordings with matching short text / description
  list<RecordingsItemPtr>::iterator recIterLow = std::lower_bound (recIterLowName, recIterUpName, dummy, RecordingsItemPtrCompare::ByAscendingName);
  list<RecordingsItemPtr>::iterator recIterUp = std::upper_bound (recIterLow, recIterUpName, dummy, RecordingsItemPtrCompare::ByAscendingName);

  if(recIterLow != recIterUp) {   // exact match found
    if (RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLow, recIterUp, dummy) > 0) return true;
    RecItem = *recIterLow;
    return true;
  }
// no exact match found, get recording with most matching characters
  int numEqualCharsLow = 0;
  int numEqualCharsUp  = 0;

  if(recIterLow != recIterLowName) { 
    --recIterLow;
    RecordingsItemPtrCompare::Compare2(numEqualCharsLow, *recIterLow, dummy);
  }
  if(recIterUp != recIterUpName)
    RecordingsItemPtrCompare::Compare2(numEqualCharsUp , *recIterUp , dummy);

  if ( numEqualCharsLow > numEqualCharsUp ) {
    if( numEqualCharsLow > 5 ) { RecItem = *recIterLow; return true; }
  } else {
    if( numEqualCharsUp  > 5 ) { RecItem = *recIterUp;  return true; }
  }


// no exact match found, get best match
  int num_match_rec = RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLowName, recIterUpName, dummy);
  if(num_match_rec == 0 || num_match_rec > 5) return false; // no matching lenght or series (too many matching length)
  return true;
}



#line 1 "page_init.eh"

// do not add to Makefile
// and do not write a ecpp comment into this file. It must produce no
// html output not even an empty line.
#include <tnt/savepoint.h>
#include <exception.h>

#line 2 "page_exit.eh"

#include <exception.h>

// </%pre>

namespace
{
class _component_ : public tnt::EcppComponent
{
    _component_& main()  { return *this; }

  protected:
    ~_component_();

  public:
    _component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl);

    unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    class channel_selection_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        channel_selection_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    class rec_item_file_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        rec_item_file_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    channel_selection_type channel_selection;
    rec_item_file_type rec_item_file;
};

static tnt::EcppComponentFactoryImpl<_component_> Factory("schedule");

static const char* rawData = "0\001\000\0001\001\000\0002\001\000\000V\001\000\000a\001\000\000d\001\000\000\252\001"
  "\000\000\255\001\000\000\305\001\000\000\310\001\000\000\312\001\000\000\004\002\000\000=\002\000\000\211\002\000\000"
  "\253\002\000\000\323\002\000\000\325\002\000\000\362\002\000\000\364\002\000\000\034\003\000\000(\003\000\0001\003"
  "\000\000<\003\000\000r\003\000\000\217\003\000\000\221\003\000\000\262\003\000\000\314\003\000\000\317\003\000\000"
  "\325\003\000\000\361\003\000\000\006\004\000\000(\004\000\000=\004\000\000^\004\000\000d\004\000\000\206\004\000\000"
  "\214\004\000\000\223\004\000\000\224\004\000\000\240\004\000\000\272\004\000\000\273\004\000\000\274\004\000\000\031"
  "\005\000\0003\005\000\000H\005\000\000N\005\000\000T\005\000\000\242\005\000\000\352\005\000\000\370\005\000\000\371"
  "\005\000\000\373\005\000\000U\006\000\000X\006\000\000r\006\000\000\177\006\000\000\216\006\000\000\231\006\000\000"
  "\363\006\000\000\366\006\000\000\375\006\000\000\024\007\000\000.\007\000\0004\007\000\000`\007\000\000\202\007\000"
  "\000\227\007\000\000\270\007\000\000\276\007\000\000\326\007\000\000\327\007\000\000\330\007\000\000\331\007\000\000"
  "\332\007\000\000\n\n\n<html>\n\t<head>\n\t\t<title>VDR Live - </title>\n\t\t\n\t\t\n\t</head>\n\t<body onload=\"adjus"
  "tHeader()\" onresize=\"adjustHeader()\">\n\t\t\n\t\t\n\t\t<div class=\"inhalt\">\n\t\t\t.\n\t\t<table class=\"listing"
  "\" cellspacing=\"0\" cellpadding=\"0\">\n\t\t\t\t<tr class=\"spacer\">\n\t\t\t\t\t<td colspan=\"5\"/>\n\t\t\t\t</tr>"
  "\n\t\t\t\t<tr class=\"head\">\n\t\t\t\t\t<td colspan=\"5\"><div class=\"boxheader\"><div><div></div></div></div></td>"
  "\n\t\t\t\t</tr>\n\t\t\t\t<tr>\n\t\t\t\t\t<td class=\"action leftcol \"></td>\n\t\t\t\t\t<td class=\"action \"><a href"
  "=\"searchresults.html\?searchplain=\"><img src=\"\" alt=\"\" ></img></a><img src=\"img/transparent.png\" width=\"16\""
  " height=\"16\"></td>\n\t\t\t\t\t<td class=\"action \"></td>\n\t\t\t\t\t<td class=\"topaligned \"><div class=\"withmar"
  "gin\"> - <br /></div></td>\n\t\t\t\t\t<td class=\" topaligned rightcol \"><div class=\"more withmargin\"><a ><span cl"
  "ass=\"title\"></span><br /><span class=\"short\">&nbsp;</span></a></div></td>\n\n\t\t\t\t</tr>\n<tr>\n \n</tr>\n\n\t"
  "\t\t</table>\n\t\t</div>\n\t</body>\n</html>\n\n\n<form action=\"schedule.html\" method=\"get\" id=\"channels\">\n   "
  "<span>\n     <label for=\"channel\">:&nbsp;<span class=\"bold\"></span></label>\n     \n     \n     \n   </span>\n</f"
  "orm>\n<span class=\"sep\">|</span>\n<a href=\"schedule.html\?channel=\">\302\253 Prev</a>\n<span class=\"sep\">|</spa"
  "n>\n<a href=\"schedule.html\?channel=\">Next \302\273</a>\n\n\n\n<td colspan=\"2\" style=\"word-wrap: normal;min-widt"
  "h: 10px;max-width: 70px;\" class=\"leftcol \">   </td>\n<td class=\"action \"> <img src=\"\" alt=\"on_dvd\"  /> </td>"
  "\n\n<td colspan=\"3\" style=\"word-wrap: normal;min-width: 10px;max-width: 70px;\" class=\"leftcol \">  </td>\n\n<td "
  "class=\"topaligned \"><div class=\"withmargin\"><br /></div></td>\n\n<td class=\"topaligned rightcol \"><div class=\""
  "more withmargin\"><a ><span class=\"title\"></span><br /><span class=\"short\">&nbsp;</span></a></div></td>\n\n\n\n\n"
  "\n";

// <%shared>
// </%shared>

// <%config>
// </%config>

_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)
  : EcppComponent(ci, um, cl),
    channel_selection(*this, "channel_selection"),
    rec_item_file(*this, "rec_item_file")
{
  // <%init>
  // </%init>
}

_component_::~_component_()
{
  // <%cleanup>
  // </%cleanup>
}

template <typename T>
inline void _tnt_ignore_unused(const T&) { }

unsigned _component_::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule " << qparam.getUrl());

  tnt::DataChunks _tntChunks(rawData);

  // <%args>
int channel = qparam.get< int >("channel", ( -1));
  // </%args>

#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 87 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
  reply.out() << _tntChunks[0]; // \n
  reply.out() << _tntChunks[1]; // \n
  // <%include> page_init.eh
#line 11 "page_init.eh"

try {
	reply.setHeader("Expires", "Mon, 26 Jul 1997 05:00:00 GMT");
	tnt::Savepoint spoint( reply );

  // </%include>
#line 90 "schedule.ecpp"

if (!logged_in && LiveSetup().UseAuth()) return reply.redirect("login.html");

#line 93 "schedule.ecpp"

	pageTitle = trVDR("Schedule");

vector<string> path;
list<RecordingsItemPtr> recItems;
RecordingsTreePtr recordingsTree(LiveRecordingsManager()->GetRecordingsTree());

addAllRecordings(recItems, recordingsTree, path);


#if VDRVERSNUM < 20301
	cSchedulesLock schedulesLock;
	cSchedules const* schedules = cSchedules::Schedules( schedulesLock );

	ReadLock channelsLock( Channels );
	if ( !channelsLock )
		throw HtmlError( tr("Couldn't aquire access to channels, please try again later.") );
#endif

	// cChannel* Channel; (see %request above)
	if ( channel > 0 ) {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
		Channel = (cChannel *)Channels->GetByNumber( channel );
#else
		Channel = Channels.GetByNumber( channel );
#endif
	}
	else {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
#endif
		if (cDevice::CurrentChannel()) {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->GetByNumber(cDevice::CurrentChannel());
#else
			Channel = Channels.GetByNumber(cDevice::CurrentChannel());
#endif
		}
		else {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->Get( Channels->GetNextNormal( -1 ) );
#else
			Channel = Channels.Get( Channels.GetNextNormal( -1 ) );
#endif
		}
	}
	if ( Channel == 0 )
		throw HtmlError( tr("Couldn't find channel or no channels available. Maybe you mistyped your request?") );

	cSchedule const* Schedule;
#if VDRVERSNUM >= 20301
	{
		LOCK_SCHEDULES_READ;
		Schedule = Schedules->GetSchedule( (const cChannel *)Channel );
	}
#else
	Schedule = schedules->GetSchedule( Channel );
#endif

  // <& pageelems.doc_type ...
  { 
#line 153 "schedule.ecpp"
    tnt::QueryParams _tnt_cq0;
#line 153 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "doc_type"), request, reply, _tnt_cq0);
    // &>
  }
  reply.out() << _tntChunks[2]; // \n<html>\n\t<head>\n\t\t<title>VDR Live - 
#line 156 "schedule.ecpp"
  reply.sout() << ( pageTitle );
  reply.out() << _tntChunks[3]; // </title>\n\t\t
  // <& pageelems.stylesheets ...
  { 
#line 157 "schedule.ecpp"
    tnt::QueryParams _tnt_cq1;
#line 157 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "stylesheets"), request, reply, _tnt_cq1);
    // &>
  }
  reply.out() << _tntChunks[4]; // \n\t\t
  // <& pageelems.ajax_js ...
  { 
#line 158 "schedule.ecpp"
    tnt::QueryParams _tnt_cq2;
#line 158 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_js"), request, reply, _tnt_cq2);
    // &>
  }
  reply.out() << _tntChunks[5]; // \n\t</head>\n\t<body onload="adjustHeader()" onresize="adjustHeader()">\n\t\t
  // <& pageelems.logo ...
  { 
#line 161 "schedule.ecpp"
    tnt::QueryParams _tnt_cq3;
#line 161 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "logo"), request, reply, _tnt_cq3);
    // &>
  }
  reply.out() << _tntChunks[6]; // \n\t\t
  // <& menu ...
  { 
#line 162 "schedule.ecpp"
    tnt::QueryParams _tnt_cq4;
#line 162 "schedule.ecpp"
    _tnt_cq4.add( "active", ("schedule"));
#line 162 "schedule.ecpp"
    _tnt_cq4.add( "component", ("schedule.channel_selection"));
#line 162 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "menu"), request, reply, _tnt_cq4);
    // &>
  }
  reply.out() << _tntChunks[7]; // \n\t\t<div class="inhalt">\n
#line 164 "schedule.ecpp"

	if ( Schedule == 0 ) {

  reply.out() << _tntChunks[8]; // \t\t\t
#line 167 "schedule.ecpp"
  reply.sout() << ( tr("No schedules available for this channel") );
  reply.out() << _tntChunks[9]; // .\n
#line 168 "schedule.ecpp"

	}
	else {

  reply.out() << _tntChunks[10]; // \t\t<table class="listing" cellspacing="0" cellpadding="0">\n
#line 173 "schedule.ecpp"

		string current_day = "";
		const cEvent* PresentEvent = Schedule->GetPresentEvent();
		time_t now = time(NULL) - ::Setup.EPGLinger * 60;
                RecordingsItemPtr recItem;
                bool recItemFound;
#if VDRVERSNUM >= 20301
		for (const cEvent *Event = (cEvent *)Schedule->Events()->First(); Event; Event = (cEvent *)Schedule->Events()->Next(Event)) {
#else
		for (const cEvent *Event = Schedule->Events()->First(); Event; Event = Schedule->Events()->Next(Event)) {
#endif
			if (Event->EndTime() <= now && Event != PresentEvent)
				continue;

			EpgInfoPtr epgEvent = EpgEvents::CreateEpgInfo(Channel, Event);

			string title(epgEvent->Title());
			string short_description(epgEvent->ShortDescr());
			string description(epgEvent->LongDescr());
			string start(epgEvent->StartTime(tr("%I:%M %p")));
			string end(epgEvent->EndTime(tr("%I:%M %p")));
                        int durationMinutes = epgEvent->Duration() / 60;
                        string duration(durationMinutes < 0 ? "" : FormatDuration(tr("(%d:%02d)"), durationMinutes / 60, durationMinutes % 60));
			string day(epgEvent->StartTime(tr("%A, %b %d %Y")));
			string epgid = EpgEvents::EncodeDomId(Channel->GetChannelID(), Event->EventID());

			bool truncated = false;
			bool lastEventCurrentDay = false;

                        recItemFound = searchNameDesc(recItem, recItems, title, short_description, description, epgEvent->Duration() );
			{
#if VDRVERSNUM >= 20301
				cEvent* NextEvent = (cEvent *)Schedule->Events()->Next(Event);
#else
				cEvent* NextEvent = Schedule->Events()->Next(Event);
#endif
				if (!NextEvent) {
					lastEventCurrentDay = true;
				}
				else {
					string nday(NextEvent->StartTime() ? FormatDateTime(tr("%A, %b %d %Y"), NextEvent->StartTime()) : "");
					lastEventCurrentDay = (day != nday);
				}
			}

			if (current_day != day) {
				if (current_day != "") {

  reply.out() << _tntChunks[11]; // \t\t\t\t<tr class="spacer">\n\t\t\t\t\t<td colspan="5"/>\n\t\t\t\t</tr>\n
#line 224 "schedule.ecpp"

				}

  reply.out() << _tntChunks[12]; // \t\t\t\t<tr class="head">\n\t\t\t\t\t<td colspan="5"><div class="boxheader"><div><div>
#line 228 "schedule.ecpp"
  reply.sout() << ( day );
  reply.out() << _tntChunks[13]; // </div></div></div></td>\n\t\t\t\t</tr>\n
#line 230 "schedule.ecpp"

				current_day = day;
			}

  reply.out() << _tntChunks[14]; // \t\t\t\t<tr>\n\t\t\t\t\t<td class="action leftcol 
#line 235 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[15]; // ">
  // <& pageelems.event_timer ...
  { 
#line 235 "schedule.ecpp"
    tnt::QueryParams _tnt_cq5;
#line 235 "schedule.ecpp"
    _tnt_cq5.add( "epgid", (epgid));
#line 235 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "event_timer"), request, reply, _tnt_cq5);
    // &>
  }
  reply.out() << _tntChunks[16]; // </td>\n\t\t\t\t\t<td class="action 
#line 236 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[17]; // ">
#line 236 "schedule.ecpp"
if (LiveFeatures<features::epgsearch>().Recent() ) { 
  reply.out() << _tntChunks[18]; // <a href="searchresults.html\?searchplain=
#line 236 "schedule.ecpp"
  reply.sout() << ( StringUrlEncode(title) );
  reply.out() << _tntChunks[19]; // "><img src="
#line 236 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "search.png") );
  reply.out() << _tntChunks[20]; // " alt="" 
  // <& tooltip.hint ...
  { 
#line 236 "schedule.ecpp"
    tnt::QueryParams _tnt_cq6;
#line 236 "schedule.ecpp"
    _tnt_cq6.add( "text", (tr("Search for repeats.")));
#line 236 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq6);
    // &>
  }
  reply.out() << _tntChunks[21]; // ></img></a>
#line 236 "schedule.ecpp"
 } else { 
  reply.out() << _tntChunks[22]; // <img src="img/transparent.png" width="16" height="16">
#line 236 "schedule.ecpp"
 } 
  reply.out() << _tntChunks[23]; // </td>\n\t\t\t\t\t<td class="action 
#line 237 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[24]; // ">
  // <& pageelems.imdb_info_href ...
  { 
#line 237 "schedule.ecpp"
    tnt::QueryParams _tnt_cq7;
#line 237 "schedule.ecpp"
    _tnt_cq7.add( "title", (title));
#line 237 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "imdb_info_href"), request, reply, _tnt_cq7);
    // &>
  }
  reply.out() << _tntChunks[25]; // </td>\n\t\t\t\t\t<td class="topaligned 
#line 238 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[26]; // "><div class="withmargin">
#line 238 "schedule.ecpp"
  reply.sout() << ( start );
  reply.out() << _tntChunks[27]; //  - 
#line 238 "schedule.ecpp"
  reply.sout() << ( end );
  reply.out() << _tntChunks[28]; // <br />
#line 238 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << _tntChunks[29]; // </div></td>\n\t\t\t\t\t<td class="
#line 239 "schedule.ecpp"
  if ( (Event == PresentEvent) )
    reply.sout() <<  "current" ;
  reply.out() << _tntChunks[30]; //  topaligned rightcol 
#line 239 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[31]; // "><div class="more withmargin"><a 
  // <& tooltip.hint ...
  { 
#line 239 "schedule.ecpp"
    tnt::QueryParams _tnt_cq8;
#line 239 "schedule.ecpp"
    _tnt_cq8.add( "text", (StringEscapeAndBreak(StringWordTruncate(description, 300, truncated)) + "<br />" + tr("Click to view details.")));
#line 239 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq8);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 239 "schedule.ecpp"
    tnt::QueryParams _tnt_cq9;
#line 239 "schedule.ecpp"
    _tnt_cq9.add( "domId", (epgEvent->Id()));
#line 239 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq9);
    // &>
  }
  reply.out() << _tntChunks[32]; // ><span class="title">
#line 239 "schedule.ecpp"
  reply.sout() << ( title );
  reply.out() << _tntChunks[33]; // </span><br /><span class="short">
#line 239 "schedule.ecpp"
if (short_description.empty()) { 
  reply.out() << _tntChunks[34]; // &nbsp;
#line 239 "schedule.ecpp"
 } 
#line 239 "schedule.ecpp"
  reply.sout() << ( short_description );
  reply.out() << _tntChunks[35]; // </span></a></div></td>\n\n\t\t\t\t</tr>\n
#line 242 "schedule.ecpp"

if(recItemFound) {
                  string r_day(FormatDateTime(tr("%a,"), recItem->StartTime()));
                  string dayLen(lexical_cast<string, int>(r_day.length() - 1) + ".25em;");
                  string duration(recItem->Duration() < 0 ? "" : FormatDuration(tr("(%d:%02d)"), recItem->Duration() / 60, recItem->Duration() % 60));
                  string shortDescr(recItem->RecInfo()->ShortText() ? recItem->RecInfo()->ShortText() : "");
                  string r_description(recItem->RecInfo()->Description() ? recItem->RecInfo()->Description() : "");
                  string hint(tr("Click to view details."));
                  if (!shortDescr.empty()) hint = shortDescr + "<br />" + hint;
                  else if (!r_description.empty()) hint = r_description + "<br />" + hint;

  reply.out() << _tntChunks[36]; // <tr>\n 
  // <& rec_item_file ...
  { 
#line 254 "schedule.ecpp"
    tnt::QueryParams _tnt_cq10;
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "archived", (RecordingsManager::GetArchiveDescr(recItem->Recording())));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "day", (r_day));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "dayLen", (dayLen));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "duration", (duration));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "hint", (hint));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "id", (recItem->Id()));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "lastEventCurrentDay", (lastEventCurrentDay));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "level", (recItem->Level()));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "name", (recItem->Name()));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "shortDescr", (shortDescr));
#line 254 "schedule.ecpp"
    _tnt_cq10.add( "startTime", (recItem->StartTime()));
#line 254 "schedule.ecpp"
  main().rec_item_file(request, reply, _tnt_cq10);
    // &>
  }
  reply.out() << _tntChunks[37]; // \n</tr>\n
#line 256 "schedule.ecpp"

}

  reply.out() << _tntChunks[38]; // \n
#line 260 "schedule.ecpp"

		}

  reply.out() << _tntChunks[39]; // \t\t\t</table>\n
#line 264 "schedule.ecpp"

	}

  reply.out() << _tntChunks[40]; // \t\t</div>\n\t</body>\n</html>\n
  // <%include> page_exit.eh
  reply.out() << _tntChunks[41]; // \n
#line 5 "page_exit.eh"

	spoint.commit();
} catch ( vdrlive::HtmlError const& ex ) {
	tnt::QueryParams param = qparam;
	param.add( "pageTitle", pageTitle );
	param.add( "errorMessage", ex.what() );
	callComp( "error", request, reply, param );
}

  // </%include>
  reply.out() << _tntChunks[42]; // \n
  reply.out() << _tntChunks[51]; // \n
  reply.out() << _tntChunks[52]; // \n\n
  reply.out() << _tntChunks[71]; // \n
  reply.out() << _tntChunks[72]; // \n
  reply.out() << _tntChunks[73]; // \n
  reply.out() << _tntChunks[74]; // \n
  // <%/cpp>
  return DEFAULT;
}

unsigned _component_::channel_selection_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::channel_selection " << qparam.getUrl());
  tnt::DataChunks _tntChunks(rawData);
#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 87 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
  reply.out() << _tntChunks[43]; // <form action="schedule.html" method="get" id="channels">\n   <span>\n     <label for="channel">
#line 275 "schedule.ecpp"
  reply.sout() << ( tr("Channel") );
  reply.out() << _tntChunks[44]; // :&nbsp;<span class="bold">
#line 275 "schedule.ecpp"
  reply.sout() << ( std::to_string(Channel->Number()) );
  reply.out() << _tntChunks[45]; // </span></label>\n     
  // <& channels_widget ...
  { 
#line 276 "schedule.ecpp"
    tnt::QueryParams _tnt_cq11;
#line 276 "schedule.ecpp"
    _tnt_cq11.add( "name", ("channel"));
#line 276 "schedule.ecpp"
    _tnt_cq11.add( "onchange", ("document.forms.channels.submit()"));
#line 276 "schedule.ecpp"
    _tnt_cq11.add( "selected", (Channel ? *Channel->GetChannelID().ToString() : ""));
#line 276 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "channels_widget"), request, reply, _tnt_cq11);
    // &>
  }
  reply.out() << _tntChunks[46]; // \n     
  // <& pageelems.ajax_action_href ...
  { 
#line 277 "schedule.ecpp"
    tnt::QueryParams _tnt_cq12;
#line 277 "schedule.ecpp"
    _tnt_cq12.add( "action", "switch_channel");
#line 277 "schedule.ecpp"
    _tnt_cq12.add( "alt", "");
#line 277 "schedule.ecpp"
    _tnt_cq12.add( "image", "zap.png");
#line 277 "schedule.ecpp"
    _tnt_cq12.add( "param", (Channel->GetChannelID()));
#line 277 "schedule.ecpp"
    _tnt_cq12.add( "tip", (tr("Switch to this channel.")));
#line 277 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_action_href"), request, reply, _tnt_cq12);
    // &>
  }
  reply.out() << _tntChunks[47]; // \n     
  // <& pageelems.m3u_playlist_channel ...
  { 
#line 278 "schedule.ecpp"
    tnt::QueryParams _tnt_cq13;
#line 278 "schedule.ecpp"
    _tnt_cq13.add( "channelId", (Channel->GetChannelID()));
#line 278 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "m3u_playlist_channel"), request, reply, _tnt_cq13);
    // &>
  }
  reply.out() << _tntChunks[48]; // \n   </span>\n</form>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 282 "schedule.ecpp"
  reply.sout() << ( std::max(0, ((int)Channel->Number() - 1)) );
  reply.out() << _tntChunks[49]; // ">\302\253 Prev</a>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 284 "schedule.ecpp"
  reply.sout() << ( (Channel->Number() + 1) );
  reply.out() << _tntChunks[50]; // ">Next \302\273</a>\n
  // <%/cpp>
  return DEFAULT;
}

unsigned _component_::rec_item_file_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::rec_item_file " << qparam.getUrl());
  tnt::DataChunks _tntChunks(rawData);
  // <%args>
string name = qparam.get< string >("name");
int level = qparam.get< int >("level");
string id = qparam.get< string >("id");
string day = qparam.get< string >("day");
string dayLen = qparam.get< string >("dayLen");
time_t startTime = qparam.get< time_t >("startTime");
string duration = qparam.get< string >("duration");
string hint = qparam.get< string >("hint");
string shortDescr = qparam.get< string >("shortDescr");
string archived = qparam.get< string >("archived");
bool lastEventCurrentDay = qparam.get< bool >("lastEventCurrentDay");
  // </%args>

#line 82 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 87 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
#line 303 "schedule.ecpp"
 if (!archived.empty()) { 
  reply.out() << _tntChunks[53]; // <td colspan="2" style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 304 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[54]; // "> 
#line 304 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << _tntChunks[55]; //   </td>\n<td class="action 
#line 305 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[56]; // "> <img src="
#line 305 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "on_dvd.png") );
  reply.out() << _tntChunks[57]; // " alt="on_dvd" 
  // <& tooltip.hint ...
  { 
#line 305 "schedule.ecpp"
    tnt::QueryParams _tnt_cq14;
#line 305 "schedule.ecpp"
    _tnt_cq14.add( "text", (archived));
#line 305 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq14);
    // &>
  }
  reply.out() << _tntChunks[58]; //  /> </td>\n\n
#line 307 "schedule.ecpp"
 } else { 
  reply.out() << _tntChunks[59]; // <td colspan="3" style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 308 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[60]; // "> 
#line 308 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << _tntChunks[61]; //  </td>\n
#line 309 "schedule.ecpp"
 } 
  reply.out() << _tntChunks[62]; // \n<td class="topaligned 
#line 311 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[63]; // "><div class="withmargin">
#line 311 "schedule.ecpp"
  reply.sout() << ( FormatDateTime(tr("%a,"), startTime) + string(" ") + FormatDateTime(tr("%b %d %y"), startTime) + string(" ") + FormatDateTime(tr("%I:%M %p"), startTime) );
  reply.out() << _tntChunks[64]; // <br />
#line 311 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << _tntChunks[65]; // </div></td>\n\n<td class="topaligned rightcol 
#line 313 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[66]; // "><div class="more withmargin"><a 
  // <& tooltip.hint ...
  { 
#line 313 "schedule.ecpp"
    tnt::QueryParams _tnt_cq15;
#line 313 "schedule.ecpp"
    _tnt_cq15.add( "text", (hint));
#line 313 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq15);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 313 "schedule.ecpp"
    tnt::QueryParams _tnt_cq16;
#line 313 "schedule.ecpp"
    _tnt_cq16.add( "domId", (id));
#line 313 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq16);
    // &>
  }
  reply.out() << _tntChunks[67]; // ><span class="title">
#line 313 "schedule.ecpp"
  reply.sout() << ( name );
  reply.out() << _tntChunks[68]; // </span><br /><span class="short">
#line 313 "schedule.ecpp"
if (shortDescr.empty()) { 
  reply.out() << _tntChunks[69]; // &nbsp;
#line 313 "schedule.ecpp"
 } 
#line 313 "schedule.ecpp"
  reply.sout() << ( shortDescr );
  reply.out() << _tntChunks[70]; // </span></a></div></td>\n\n
  // <%/cpp>
  return DEFAULT;
}

} // namespace
